@@ -7,16 +7,29 @@ import platform
 from xml.dom.minidom import parse
 
 from qt_material.resources import ResourseGenerator, RESOURCES_PATH
+
 GUI = True
 
 if 'PySide2' in sys.modules:
-    from PySide2.QtGui import QFontDatabase, QColor, QGuiApplication, QPalette
+    from PySide2.QtGui import (
+        QFontDatabase,
+        QColor,
+        QGuiApplication,
+        QPalette,
+    )
     from PySide2.QtWidgets import QAction, QColorDialog, QActionGroup
     from PySide2.QtUiTools import QUiLoader
     from PySide2.QtCore import Qt, QDir
 
 elif 'PySide6' in sys.modules:
-    from PySide6.QtGui import QFontDatabase, QAction, QColor, QGuiApplication, QPalette, QActionGroup
+    from PySide6.QtGui import (
+        QFontDatabase,
+        QAction,
+        QColor,
+        QGuiApplication,
+        QPalette,
+        QActionGroup,
+    )
     from PySide6.QtWidgets import QColorDialog
     from PySide6.QtUiTools import QUiLoader
     from PySide6.QtCore import Qt, QDir
@@ -28,7 +41,14 @@ elif 'PyQt5' in sys.modules:
     from PyQt5 import uic
 
 elif 'PyQt6' in sys.modules:
-    from PyQt6.QtGui import QFontDatabase, QColor, QGuiApplication, QPalette, QAction, QActionGroup
+    from PyQt6.QtGui import (
+        QFontDatabase,
+        QColor,
+        QGuiApplication,
+        QPalette,
+        QAction,
+        QActionGroup,
+    )
     from PyQt6.QtWidgets import QColorDialog
     from PyQt6.QtCore import Qt, QDir
     from PyQt6 import uic
@@ -38,18 +58,28 @@ else:
 
 import jinja2
 
-TEMPLATE_FILE = os.path.join(os.path.dirname(
-    os.path.abspath(__file__)), 'material.css.template')
+TEMPLATE_FILE = os.path.join(
+    os.path.dirname(os.path.abspath(__file__)), 'material.css.template'
+)
 
 
 # ----------------------------------------------------------------------
-def export_theme(theme='', qss=None, rcc=None, invert_secondary=False, extra={}, output='theme', prefix='icon:/'):
+def export_theme(
+    theme='',
+    qss=None,
+    rcc=None,
+    invert_secondary=False,
+    extra={},
+    output='theme',
+    prefix='icon:/',
+):
     """"""
     if not os.path.isabs(output) and not output.startswith('.'):
-            output = f'.{output}'
+        output = f'.{output}'
 
     stylesheet = build_stylesheet(
-        theme, invert_secondary, extra, output, export=True)
+        theme, invert_secondary, extra, output, export=True
+    )
 
     if output.startswith('.'):
         output = output[1:]
@@ -64,12 +94,14 @@ def export_theme(theme='', qss=None, rcc=None, invert_secondary=False, extra={},
             file.write(f'  <qresource prefix="{prefix[:-2]}">\n')
 
             for subfolder in ['disabled', 'primary']:
-                files = os.listdir(os.path.join(
-                    os.path.abspath(output), subfolder))
+                files = os.listdir(
+                    os.path.join(os.path.abspath(output), subfolder)
+                )
                 files = filter(lambda s: s.endswith('svg'), files)
                 for filename in files:
                     file.write(
-                        f'    <file>{output}/{subfolder}/{filename}</file>\n')
+                        f'    <file>{output}/{subfolder}/{filename}</file>\n'
+                    )
 
             file.write('  </qresource>\n')
 
@@ -82,7 +114,14 @@ def export_theme(theme='', qss=None, rcc=None, invert_secondary=False, extra={},
 
 
 # ----------------------------------------------------------------------
-def build_stylesheet(theme='', invert_secondary=False, extra={}, parent='theme', template=TEMPLATE_FILE, export=False):
+def build_stylesheet(
+    theme='',
+    invert_secondary=False,
+    extra={},
+    parent='theme',
+    template=TEMPLATE_FILE,
+    export=False,
+):
     """"""
 
     if not export:
@@ -123,11 +162,18 @@ def build_stylesheet(theme='', invert_secondary=False, extra={}, parent='theme',
 
     if GUI:
         default_palette = QGuiApplication.palette()
-        color = QColor(*[int(theme['primaryColor'][i:i + 2], 16)
-                         for i in range(1, 6, 2)] + [92])
+        color = QColor(
+            *[
+                int(theme['primaryColor'][i : i + 2], 16)
+                for i in range(1, 6, 2)
+            ]
+            + [92]
+        )
 
         try:
-            if hasattr(QPalette, 'PlaceholderText'):  # pyqt5, pyside2, pyside6
+            if hasattr(
+                QPalette, 'PlaceholderText'
+            ):  # pyqt5, pyside2, pyside6
                 default_palette.setColor(QPalette.PlaceholderText, color)
             else:  # pyqt6
                 default_palette.setColor(QPalette.ColorRole.Text, color)
@@ -138,11 +184,9 @@ def build_stylesheet(theme='', invert_secondary=False, extra={}, parent='theme',
             QGuiApplication.set_palette(default_palette)
 
     environ = {
-
         'linux': platform.system() == 'Linux',
         'windows': platform.system() == 'Windows',
         'darwin': platform.system() == 'Darwin',
-
         'pyqt5': 'PyQt5' in sys.modules,
         'pyqt6': 'PyQt6' in sys.modules,
         'pyside2': 'PySide2' in sys.modules,
@@ -155,16 +199,34 @@ def build_stylesheet(theme='', invert_secondary=False, extra={}, parent='theme',
 
 # ----------------------------------------------------------------------
 def get_theme(theme_name, invert_secondary=False):
-    if theme_name in ['default.xml', 'default_dark.xml', 'default', 'default_dark']:
-        theme = os.path.join(os.path.dirname(
-            os.path.abspath(__file__)), 'themes', 'dark_teal.xml')
-    elif theme_name in ['default_light.xml', 'default_light']:
+    if theme_name in [
+        # 'default.xml',
+        # 'default',
+        'default_dark.xml',
+        'default_dark',
+    ]:
+        theme = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            'themes',
+            'dark_teal.xml',
+            # 'light_cyan_500.xml',
+        )
+    elif theme_name in [
+        'default_light.xml',
+        'default_light',
+        'default.xml',
+        'default',
+    ]:
         invert_secondary = True
-        theme = os.path.join(os.path.dirname(
-            os.path.abspath(__file__)), 'themes', 'light_blue.xml')
+        theme = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            'themes',
+            'light_cyan_500.xml',
+        )
     elif not os.path.exists(theme_name):
-        theme = os.path.join(os.path.dirname(
-            os.path.abspath(__file__)), 'themes', theme_name)
+        theme = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)), 'themes', theme_name
+        )
     else:
         theme = theme_name
 
@@ -173,23 +235,34 @@ def get_theme(theme_name, invert_secondary=False):
         return None
 
     document = parse(theme)
-    theme = {child.getAttribute(
-        'name'): child.firstChild.nodeValue for child in document.getElementsByTagName('color')}
+    theme = {
+        child.getAttribute('name'): child.firstChild.nodeValue
+        for child in document.getElementsByTagName('color')
+    }
 
     for k in theme:
         os.environ[str(k)] = theme[k]
 
     if invert_secondary:
-        theme['secondaryColor'], theme['secondaryLightColor'], theme['secondaryDarkColor'] = theme[
-            'secondaryColor'], theme['secondaryDarkColor'], theme['secondaryLightColor']
+        (
+            theme['secondaryColor'],
+            theme['secondaryLightColor'],
+            theme['secondaryDarkColor'],
+        ) = (
+            theme['secondaryColor'],
+            theme['secondaryDarkColor'],
+            theme['secondaryLightColor'],
+        )
 
-    for color in ['primaryColor',
-                  'primaryLightColor',
-                  'secondaryColor',
-                  'secondaryLightColor',
-                  'secondaryDarkColor',
-                  'primaryTextColor',
-                  'secondaryTextColor']:
+    for color in [
+        'primaryColor',
+        'primaryLightColor',
+        'secondaryColor',
+        'secondaryLightColor',
+        'secondaryDarkColor',
+        'primaryTextColor',
+        'secondaryTextColor',
+    ]:
         os.environ[f'QTMATERIAL_{color.upper()}'] = theme[color]
     os.environ['QTMATERIAL_THEME'] = theme_name
 
@@ -202,17 +275,30 @@ def add_fonts():
     fonts_path = os.path.join(os.path.dirname(__file__), 'fonts')
 
     for font_dir in ['roboto']:
-        for font in filter(lambda s: s.endswith('.ttf'), os.listdir(os.path.join(fonts_path, font_dir))):
+        for font in filter(
+            lambda s: s.endswith('.ttf'),
+            os.listdir(os.path.join(fonts_path, font_dir)),
+        ):
             try:
                 QFontDatabase.addApplicationFont(
-                    os.path.join(fonts_path, font_dir, font))
+                    os.path.join(fonts_path, font_dir, font)
+                )
             except:  # snake_case, true_property
                 QFontDatabase.add_application_font(
-                    os.path.join(fonts_path, font_dir, font))
+                    os.path.join(fonts_path, font_dir, font)
+                )
 
 
 # ----------------------------------------------------------------------
-def apply_stylesheet(app, theme='', style=None, save_as=None, invert_secondary=False, extra={}, parent='theme'):
+def apply_stylesheet(
+    app,
+    theme='',
+    style=None,
+    save_as=None,
+    invert_secondary=False,
+    extra={},
+    parent='theme',
+):
     """"""
     if style:
         try:
@@ -224,8 +310,7 @@ def apply_stylesheet(app, theme='', style=None, save_as=None, invert_secondary=F
             logging.error(f"The style '{style}' does not exist.")
             pass
 
-    stylesheet = build_stylesheet(
-        theme, invert_secondary, extra, parent)
+    stylesheet = build_stylesheet(theme, invert_secondary, extra, parent)
     if stylesheet is None:
         return
 
@@ -261,8 +346,9 @@ def density(value, density_scale, border=0, scale=1, density_interval=4):
     if isinstance(value, str):
         value = float(value.replace('px', ''))
 
-    density = (value + (density_interval * int(density_scale)) -
-               (border * 2)) * scale
+    density = (
+        value + (density_interval * int(density_scale)) - (border * 2)
+    ) * scale
 
     if density < 0:
         density = 0
@@ -273,26 +359,36 @@ def density(value, density_scale, border=0, scale=1, density_interval=4):
 def set_icons_theme(theme, parent='theme'):
     """"""
     source = os.path.join(os.path.dirname(__file__), 'resources', 'source')
-    resources = ResourseGenerator(primary=theme['primaryColor'], secondary=theme['secondaryColor'],
-                                  disabled=theme['secondaryLightColor'], source=source, parent=parent)
+    resources = ResourseGenerator(
+        primary=theme['primaryColor'],
+        secondary=theme['secondaryColor'],
+        disabled=theme['secondaryLightColor'],
+        source=source,
+        parent=parent,
+    )
     resources.generate()
 
     if GUI:
         try:
             QDir.addSearchPath('icon', resources.index)
-            QDir.addSearchPath('qt_material', os.path.join(
-                os.path.dirname(__file__), 'resources'))
+            QDir.addSearchPath(
+                'qt_material',
+                os.path.join(os.path.dirname(__file__), 'resources'),
+            )
         except:  # snake_case, true_property
             QDir.add_search_path('icon', resources.index)
-            QDir.add_search_path('qt_material', os.path.join(
-                os.path.dirname(__file__), 'resources'))
+            QDir.add_search_path(
+                'qt_material',
+                os.path.join(os.path.dirname(__file__), 'resources'),
+            )
 
 
 # ----------------------------------------------------------------------
 def list_themes():
     """"""
-    themes = os.listdir(os.path.join(
-        os.path.dirname(os.path.abspath(__file__)), 'themes'))
+    themes = os.listdir(
+        os.path.join(os.path.dirname(os.path.abspath(__file__)), 'themes')
+    )
     themes = filter(lambda a: a.endswith('xml'), themes)
     return sorted(list(themes))
 
@@ -305,8 +401,10 @@ def deprecated(replace):
         # ----------------------------------------------------------------------
         def wrap2(*args, **kwargs):
             logging.warning(
-                f'This function is deprecated, please use "{replace}" instead.')
+                f'This function is deprecated, please use "{replace}" instead.'
+            )
             fn(*args, **kwargs)
+
         return wrap2
 
     return wrap1
@@ -315,6 +413,7 @@ def deprecated(replace):
 ########################################################################
 class QtStyleTools:
     """"""
+
     extra_values = {}
 
     # ----------------------------------------------------------------------
@@ -391,26 +490,35 @@ class QtStyleTools:
 
     # # ----------------------------------------------------------------------
     # def _wrapper(self, parent, theme, extra, callable_):
-        # """"""
-        # def iner():
-            # self._apply_theme(parent, theme, extra, callable_)
-        # return iner
+    # """"""
+    # def iner():
+    # self._apply_theme(parent, theme, extra, callable_)
+    # return iner
 
     # # ----------------------------------------------------------------------
     # def _apply_theme(self, parent, theme, extra={}, callable_=None):
-        # """"""
-        # self.apply_stylesheet(parent, theme=theme, invert_secondary=theme.startswith(
-            # 'light'), extra=extra, callable_=callable_)
+    # """"""
+    # self.apply_stylesheet(parent, theme=theme, invert_secondary=theme.startswith(
+    # 'light'), extra=extra, callable_=callable_)
 
     # ----------------------------------------------------------------------
-
-    def apply_stylesheet(self, parent, theme, invert_secondary=False, extra={}, callable_=None):
+    def apply_stylesheet(
+        self, parent, theme, invert_secondary=False, extra={}, callable_=None
+    ):
         """"""
         if theme == 'default':
-            parent.setStyleSheet('')
+            try:
+                parent.setStyleSheet('')
+            except:
+                parent.style_sheet = ''
             return
-        apply_stylesheet(parent, theme=theme,
-                         invert_secondary=invert_secondary, extra=extra)
+
+        apply_stylesheet(
+            parent,
+            theme=theme,
+            invert_secondary=invert_secondary,
+            extra=extra,
+        )
 
         if callable_:
             callable_()
@@ -419,20 +527,37 @@ class QtStyleTools:
     def update_theme_event(self, parent):
         """"""
         try:
-            density = [action.text() for action in self.menu_density_.actions(
-            ) if action.isChecked()][0]
-            theme = [action.text() for action in self.menu_theme_.actions()
-                     if action.isChecked()][0]
+            density = [
+                action.text()
+                for action in self.menu_density_.actions()
+                if action.isChecked()
+            ][0]
+            theme = [
+                action.text()
+                for action in self.menu_theme_.actions()
+                if action.isChecked()
+            ][0]
         except:
             density = [
-                action.text for action in self.menu_density_.actions() if action.checked][0]
-            theme = [action.text for action in self.menu_theme_.actions()
-                     if action.checked][0]
+                action.text
+                for action in self.menu_density_.actions()
+                if action.checked
+            ][0]
+            theme = [
+                action.text
+                for action in self.menu_theme_.actions()
+                if action.checked
+            ][0]
 
         self.extra_values['density_scale'] = density
 
-        self.apply_stylesheet(parent, theme=theme, invert_secondary=theme.startswith(
-            'light'), extra=self.extra_values, callable_=self.update_buttons)
+        self.apply_stylesheet(
+            parent,
+            theme=theme,
+            invert_secondary=theme.startswith('light'),
+            extra=self.extra_values,
+            callable_=self.update_buttons,
+        )
 
     # ----------------------------------------------------------------------
     def update_buttons(self):
@@ -440,8 +565,10 @@ class QtStyleTools:
         if not hasattr(self, 'colors'):
             return
 
-        theme = {color_: os.environ[f'QTMATERIAL_{color_.upper()}']
-                 for color_ in self.colors}
+        theme = {
+            color_: os.environ[f'QTMATERIAL_{color_.upper()}']
+            for color_ in self.colors
+        }
 
         if 'light' in os.environ['QTMATERIAL_THEME']:
             self.dock_theme.checkBox_ligh_theme.setChecked(True)
@@ -450,12 +577,26 @@ class QtStyleTools:
 
         try:
             if self.dock_theme.checkBox_ligh_theme.isChecked():
-                theme['secondaryColor'], theme['secondaryLightColor'], theme['secondaryDarkColor'] = theme[
-                    'secondaryColor'], theme['secondaryDarkColor'], theme['secondaryLightColor']
+                (
+                    theme['secondaryColor'],
+                    theme['secondaryLightColor'],
+                    theme['secondaryDarkColor'],
+                ) = (
+                    theme['secondaryColor'],
+                    theme['secondaryDarkColor'],
+                    theme['secondaryLightColor'],
+                )
         except:  # snake_case, true_property
             if self.dock_theme.checkBox_ligh_theme.checked:
-                theme['secondaryColor'], theme['secondaryLightColor'], theme['secondaryDarkColor'] = theme[
-                    'secondaryColor'], theme['secondaryDarkColor'], theme['secondaryLightColor']
+                (
+                    theme['secondaryColor'],
+                    theme['secondaryLightColor'],
+                    theme['secondaryDarkColor'],
+                ) = (
+                    theme['secondaryColor'],
+                    theme['secondaryDarkColor'],
+                    theme['secondaryLightColor'],
+                )
 
         for color_ in self.colors:
             button = getattr(self.dock_theme, f'pushButton_{color_}')
@@ -473,25 +614,28 @@ class QtStyleTools:
                 else:
                     text_color = '#000000'
 
-            button.setStyleSheet(f"""
+            button.setStyleSheet(
+                f"""
             *{{
             background-color: {color};
             color: {text_color};
             border: none;
-            }}""")
+            }}"""
+            )
 
             self.custom_colors[color_] = color
 
     # ----------------------------------------------------------------------
     def get_color(self, color):
         """"""
-        return QColor(*[int(color[s:s + 2], 16) for s in range(1, 6, 2)])
+        return QColor(*[int(color[s : s + 2], 16) for s in range(1, 6, 2)])
 
     # ----------------------------------------------------------------------
     def update_theme(self, parent):
         """"""
         with open('my_theme.xml', 'w') as file:
-            file.write("""
+            file.write(
+                """
             <resources>
                 <color name="primaryColor">{primaryColor}</color>
                 <color name="primaryLightColor">{primaryLightColor}</color>
@@ -501,18 +645,27 @@ class QtStyleTools:
                 <color name="primaryTextColor">{primaryTextColor}</color>
                 <color name="secondaryTextColor">{secondaryTextColor}</color>
               </resources>
-            """.format(**self.custom_colors))
+            """.format(
+                    **self.custom_colors
+                )
+            )
         try:
             light = self.dock_theme.checkBox_ligh_theme.isChecked()
         except:  # snake_case, true_property
             light = self.dock_theme.checkBox_ligh_theme.checked
 
-        self.apply_stylesheet(parent, 'my_theme.xml', invert_secondary=light,
-                              extra=self.extra_values, callable_=self.update_buttons)
+        self.apply_stylesheet(
+            parent,
+            'my_theme.xml',
+            invert_secondary=light,
+            extra=self.extra_values,
+            callable_=self.update_buttons,
+        )
 
     # ----------------------------------------------------------------------
     def set_color(self, parent, button_):
         """"""
+
         def iner():
             initial = self.get_color(self.custom_colors[button_])
             color_dialog = QColorDialog(parent=parent)
@@ -530,15 +683,17 @@ class QtStyleTools:
             try:
                 if done and color_.isValid():
                     rgb_255 = [color_.red(), color_.green(), color_.blue()]
-                    color = '#' + ''.join([hex(v)[2:].ljust(2, '0')
-                                           for v in rgb_255])
+                    color = '#' + ''.join(
+                        [hex(v)[2:].ljust(2, '0') for v in rgb_255]
+                    )
                     self.custom_colors[button_] = color
                     self.update_theme(parent)
             except:  # snake_case, true_property
                 if done and color_.is_valid():
                     rgb_255 = [color_.red(), color_.green(), color_.blue()]
-                    color = '#' + ''.join([hex(v)[2:].ljust(2, '0')
-                                           for v in rgb_255])
+                    color = '#' + ''.join(
+                        [hex(v)[2:].ljust(2, '0') for v in rgb_255]
+                    )
                     self.custom_colors[button_] = color
                     self.update_theme(parent)
 
@@ -547,36 +702,44 @@ class QtStyleTools:
     # ----------------------------------------------------------------------
     def show_dock_theme(self, parent):
         """"""
-        self.colors = ['primaryColor',
-                       'primaryLightColor',
-                       'secondaryColor',
-                       'secondaryLightColor',
-                       'secondaryDarkColor',
-                       'primaryTextColor',
-                       'secondaryTextColor']
+        self.colors = [
+            'primaryColor',
+            'primaryLightColor',
+            'secondaryColor',
+            'secondaryLightColor',
+            'secondaryDarkColor',
+            'primaryTextColor',
+            'secondaryTextColor',
+        ]
 
         self.custom_colors = {
-            v: os.environ[f'QTMATERIAL_{v.upper()}'] for v in self.colors}
+            v: os.environ[f'QTMATERIAL_{v.upper()}'] for v in self.colors
+        }
 
         if 'PySide2' in sys.modules or 'PySide6' in sys.modules:
-            self.dock_theme = QUiLoader().load(os.path.join(
-                os.path.dirname(__file__), 'dock_theme.ui'))
+            self.dock_theme = QUiLoader().load(
+                os.path.join(os.path.dirname(__file__), 'dock_theme.ui')
+            )
         elif 'PyQt5' in sys.modules or 'PyQt6' in sys.modules:
-            self.dock_theme = uic.loadUi(os.path.join(
-                os.path.dirname(__file__), 'dock_theme.ui'))
+            self.dock_theme = uic.loadUi(
+                os.path.join(os.path.dirname(__file__), 'dock_theme.ui')
+            )
 
         try:
             parent.addDockWidget(
-                Qt.DockWidgetArea.LeftDockWidgetArea, self.dock_theme)
+                Qt.DockWidgetArea.LeftDockWidgetArea, self.dock_theme
+            )
             self.dock_theme.setFloating(True)
         except:  # snake_case, true_property
             parent.add_dock_widget(
-                Qt.DockWidgetArea.LeftDockWidgetArea, self.dock_theme)
+                Qt.DockWidgetArea.LeftDockWidgetArea, self.dock_theme
+            )
             self.dock_theme.floating = True
 
         self.update_buttons()
         self.dock_theme.checkBox_ligh_theme.clicked.connect(
-            lambda: self.update_theme(self.main))
+            lambda: self.update_theme(self.main)
+        )
 
         for color in self.colors:
             button = getattr(self.dock_theme, f'pushButton_{color}')
